@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2017 KeePassXC Team <team@keepassxc.org>
+ *  Copyright (C) 2019 KeePassXC Team <team@keepassxc.org>
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,15 +18,14 @@
 #ifndef KEEPASSXC_LOCATE_H
 #define KEEPASSXC_LOCATE_H
 
-#include "Command.h"
+#include "DatabaseCommand.h"
 
-class Locate : public Command
+class Locate : public DatabaseCommand
 {
 public:
     Locate();
-    ~Locate();
-    int execute(const QStringList& arguments);
-    int locateEntry(Database* database, QString searchTerm);
+
+    int executeWithDatabase(QSharedPointer<Database> db, QSharedPointer<QCommandLineParser> parser) override;
 };
 
 #endif // KEEPASSXC_LOCATE_H
